@@ -21,10 +21,10 @@
 
 #include <qtest.h>
 
-#include "kimap2test/fakeserver.h"
-#include "kimap2/session.h"
-#include "kimap2/logoutjob.h"
-#include "kimap2/loginjob.h"
+#include "kimaptest/fakeserver.h"
+#include "kimap/session.h"
+#include "kimap/logoutjob.h"
+#include "kimap/loginjob.h"
 
 #include <QtTest>
 
@@ -44,9 +44,9 @@ private Q_SLOTS:
                               );
         fakeServer.startAndWait();
 
-        KIMAP2::Session *session = new KIMAP2::Session(QStringLiteral("127.0.0.1"), 5989);
+        KIMAP::Session *session = new KIMAP::Session(QLatin1String("127.0.0.1"), 5989);
 
-        KIMAP2::LogoutJob *logout = new KIMAP2::LogoutJob(session);
+        KIMAP::LogoutJob *logout = new KIMAP::LogoutJob(session);
         QVERIFY(logout->exec());
 
         fakeServer.quit();
@@ -64,9 +64,9 @@ private Q_SLOTS:
                               );
         fakeServer.startAndWait();
 
-        KIMAP2::Session *session = new KIMAP2::Session(QStringLiteral("127.0.0.1"), 5989);
+        KIMAP::Session *session = new KIMAP::Session(QLatin1String("127.0.0.1"), 5989);
 
-        KIMAP2::LogoutJob *logout = new KIMAP2::LogoutJob(session);
+        KIMAP::LogoutJob *logout = new KIMAP::LogoutJob(session);
         QVERIFY(logout->exec());
 
         fakeServer.quit();
