@@ -18,9 +18,9 @@
 
 #include <qtest.h>
 
-#include "kimap2test/fakeserver.h"
-#include "kimap2/session.h"
-#include "kimap2/setmetadatajob.h"
+#include "kimaptest/fakeserver.h"
+#include "kimap/session.h"
+#include "kimap/setmetadatajob.h"
 
 #include <QtTest>
 
@@ -100,10 +100,10 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP2::Session session(QStringLiteral("127.0.0.1"), 5989);
+        KIMAP::Session session(QLatin1String("127.0.0.1"), 5989);
 
-        KIMAP2::SetMetaDataJob *setMetadataJob = new KIMAP2::SetMetaDataJob(&session);
-        setMetadataJob->setServerCapability(KIMAP2::MetaDataJobBase::Metadata);
+        KIMAP::SetMetaDataJob *setMetadataJob = new KIMAP::SetMetaDataJob(&session);
+        setMetadataJob->setServerCapability(KIMAP::MetaDataJobBase::Metadata);
         setMetadataJob->setMailBox(mailbox);
         foreach (const QByteArray &entry, annotations.keys()) {
             setMetadataJob->addMetaData(entry, annotations[entry]);
@@ -145,18 +145,15 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP2::Session session(QStringLiteral("127.0.0.1"), 5989);
+        KIMAP::Session session(QLatin1String("127.0.0.1"), 5989);
 
-        KIMAP2::SetMetaDataJob *setMetadataJob = new KIMAP2::SetMetaDataJob(&session);
-        setMetadataJob->setServerCapability(KIMAP2::MetaDataJobBase::Annotatemore);
+        KIMAP::SetMetaDataJob *setMetadataJob = new KIMAP::SetMetaDataJob(&session);
+        setMetadataJob->setServerCapability(KIMAP::MetaDataJobBase::Annotatemore);
         setMetadataJob->setMailBox(mailbox);
         foreach (const QByteArray &entry, annotations.keys()) {
             if (legacyMode) {
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wdeprecated-declarations"
                 setMetadataJob->setEntry(entry);
                 setMetadataJob->addMetaData("value.shared", annotations[entry]);
-#pragma clang diagnostic pop
             } else {
                 setMetadataJob->addMetaData(QByteArray("/shared") + entry, annotations[entry]);
             }
