@@ -1,6 +1,5 @@
 /*
     Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
-    Copyright (c) 2017 Christian Mollekopf <mollekopf@kolabsys.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -20,13 +19,15 @@
 
 #include "fetchjob.h"
 
+#include <QtCore/QTimer>
 #include "kimap_debug.h"
+#include <KLocalizedString>
 
 #include "job_p.h"
 #include "message_p.h"
 #include "session_p.h"
 
-namespace KIMAP2
+namespace KIMAP
 {
 class FetchJobPrivate : public JobPrivate
 {
@@ -35,7 +36,7 @@ public:
         : JobPrivate(session, name)
         , q(job)
         , uidBased(false)
-        , avoidParsing(false)
+        , gmailEnabled(false)
     { }
 
     ~FetchJobPrivate()
@@ -47,41 +48,83 @@ public:
     QByteArray parseSentence(const QByteArray &structure, int &pos);
     void skipLeadingSpaces(const QByteArray &structure, int &pos);
 
+    void emitPendings()
+    {
+        if (pendingUids.isEmpty()) {
+            return;
+        }
+
+        if (!pendingParts.isEmpty()) {
+            emit q->partsReceived(selectedMailBox,
+                                  pendingUids, pendingParts);
+            emit q->partsReceived(selectedMailBox,
+                                  pendingUids, pendingAttributes,
+                                  pendingParts);
+        }
+        if (!pendingSizes.isEmpty() || !pendingFlags.isEmpty() || !pendingMessages.isEmpty()) {
+            emit q->headersReceived(selectedMailBox,
+                                    pendingUids, pendingSizes,
+                                    pendingFlags, pendingMessages);
+            emit q->headersReceived(selectedMailBox,
+                                    pendingUids, pendingSizes,
+                                    pendingAttributes, pendingFlags,
+                                    pendingMessages);
+        }
+        if (!pendingMessages.isEmpty()) {
+            emit q->messagesReceived(selectedMailBox,
+                                     pendingUids, pendingMessages);
+            emit q->messagesReceived(selectedMailBox,
+                                     pendingUids, pendingAttributes,
+                                     pendingMessages);
+        }
+
+        pendingUids.clear();
+        pendingMessages.clear();
+        pendingParts.clear();
+        pendingSizes.clear();
+        pendingFlags.clear();
+        pendingAttributes.clear();
+    }
+
     FetchJob *const q;
 
     ImapSet set;
     bool uidBased;
     FetchJob::FetchScope scope;
     QString selectedMailBox;
-    bool avoidParsing;
+    bool gmailEnabled;
+
+    QTimer emitPendingsTimer;
+    QMap<qint64, MessagePtr> pendingMessages;
+    QMap<qint64, MessageParts> pendingParts;
+    QMap<qint64, MessageFlags> pendingFlags;
+    QMap<qint64, MessageAttribute> pendingAttributes;
+    QMap<qint64, qint64> pendingSizes;
+    QMap<qint64, qint64> pendingUids;
 };
 }
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 FetchJob::FetchScope::FetchScope():
     mode(FetchScope::Content),
-    changedSince(0),
-    gmailExtensionsEnabled(false)
+    changedSince(0)
 {
 
 }
 
 FetchJob::FetchJob(Session *session)
-    : Job(*new FetchJobPrivate(this, session, "Fetch"))
+    : Job(*new FetchJobPrivate(this, session, i18n("Fetch")))
 {
+    Q_D(FetchJob);
+    connect(&d->emitPendingsTimer, SIGNAL(timeout()),
+            this, SLOT(emitPendings()));
 }
 
 FetchJob::~FetchJob()
 {
 }
 
-void FetchJob::setAvoidParsing(bool avoid)
-{
-    Q_D(FetchJob);
-    d->avoidParsing = avoid;
-}
-
 void FetchJob::setSequenceSet(const ImapSet &set)
 {
     Q_D(FetchJob);
@@ -119,6 +162,43 @@ FetchJob::FetchScope FetchJob::scope() const
     return d->scope;
 }
 
+bool FetchJob::setGmailExtensionsEnabled() const
+{
+    Q_D(const FetchJob);
+    return d->gmailEnabled;
+}
+
+void FetchJob::setGmailExtensionsEnabled(bool enabled)
+{
+    Q_D(FetchJob);
+    d->gmailEnabled = enabled;
+}
+
+QMap<qint64, MessagePtr> FetchJob::messages() const
+{
+    return QMap<qint64, MessagePtr>();
+}
+
+QMap<qint64, MessageParts> FetchJob::parts() const
+{
+    return QMap<qint64, MessageParts>();
+}
+
+QMap<qint64, MessageFlags> FetchJob::flags() const
+{
+    return QMap<qint64, MessageFlags>();
+}
+
+QMap<qint64, qint64> FetchJob::sizes() const
+{
+    return QMap<qint64, qint64>();
+}
+
+QMap<qint64, qint64> FetchJob::uids() const
+{
+    return QMap<qint64, qint64>();
+}
+
 void FetchJob::doStart()
 {
     Q_D(FetchJob);
@@ -174,7 +254,7 @@ void FetchJob::doStart()
         break;
     }
 
-    if (d->scope.gmailExtensionsEnabled) {
+    if (d->gmailEnabled) {
         parameters += " X-GM-LABELS X-GM-MSGID X-GM-THRID";
     }
     parameters += ")";
@@ -188,114 +268,127 @@ void FetchJob::doStart()
         command = "UID " + command;
     }
 
+    d->emitPendingsTimer.start(100);
     d->selectedMailBox = d->m_session->selectedMailBox();
-    d->sendCommand(command, parameters);
+    d->tags << d->sessionInternal()->sendCommand(command, parameters);
 }
 
 void FetchJob::handleResponse(const Message &response)
 {
     Q_D(FetchJob);
 
+    // We can predict it'll be handled by handleErrorReplies() so stop
+    // the timer now so that result() will really be the last emitted signal.
+    if (!response.content.isEmpty() &&
+            d->tags.size() == 1 &&
+            d->tags.contains(response.content.first().toString())) {
+        d->emitPendingsTimer.stop();
+        d->emitPendings();
+    }
+
     if (handleErrorReplies(response) == NotHandled) {
         if (response.content.size() == 4 &&
                 response.content[2].toString() == "FETCH" &&
                 response.content[3].type() == Message::Part::List) {
 
-            const QList<QByteArray> content = response.content[3].toList();
+            qint64 id = response.content[1].toString().toLongLong();
+            QList<QByteArray> content = response.content[3].toList();
 
-            Result result;
-            result.sequenceNumber = response.content[1].toString().toLongLong();
+            MessagePtr message(new KMime::Message);
             bool shouldParseMessage = false;
+            MessageParts parts;
+
             for (QList<QByteArray>::ConstIterator it = content.constBegin();
                     it != content.constEnd(); ++it) {
                 QByteArray str = *it;
                 ++it;
+
                 if (it == content.constEnd()) {   // Uh oh, message was truncated?
-                    qCWarning(KIMAP2_LOG) << "FETCH reply got truncated, skipping.";
-                    qCWarning(KIMAP2_LOG) << response.toString();
-                    qCWarning(KIMAP2_LOG) << result.sequenceNumber;
-                    qCWarning(KIMAP2_LOG) << content;
-                    qCWarning(KIMAP2_LOG) << str;
+                    qCWarning(KIMAP_LOG) << "FETCH reply got truncated, skipping.";
                     break;
                 }
 
                 if (str == "UID") {
-                    result.uid = it->toLongLong();
+                    d->pendingUids[id] = it->toLongLong();
                 } else if (str == "RFC822.SIZE") {
-                    result.size = it->toLongLong();
+                    d->pendingSizes[id] = it->toLongLong();
                 } else if (str == "INTERNALDATE") {
-                    if (!result.message) {
-                        result.message = MessagePtr(new KMime::Message);
-                    }
-                    result.message->date()->setDateTime(QDateTime::fromString(QLatin1String(*it), Qt::RFC2822Date));
+                    //QT5 port to QDateTime
+                    message->date()->setDateTime(QDateTime::fromString(QLatin1String(*it), Qt::RFC2822Date));
                 } else if (str == "FLAGS") {
                     if ((*it).startsWith('(') && (*it).endsWith(')')) {
                         QByteArray str = *it;
                         str.chop(1);
                         str.remove(0, 1);
-                        result.flags = str.split(' ');
+                        d->pendingFlags[id] = str.split(' ');
                     } else {
-                        result.flags << *it;
+                        d->pendingFlags[id] << *it;
                     }
                 } else if (str == "X-GM-LABELS") {
-                    result.attributes << qMakePair<QByteArray, QVariant>("X-GM-LABELS", *it);
+                    d->pendingAttributes.insert(id, qMakePair<QByteArray, QVariant>("X-GM-LABELS", *it));
                 } else if (str == "X-GM-THRID") {
-                    result.attributes << qMakePair<QByteArray, QVariant>("X-GM-THRID", *it);
+                    d->pendingAttributes.insert(id, qMakePair<QByteArray, QVariant>("X-GM-THRID", *it));
                 } else if (str == "X-GM-MSGID") {
-                    result.attributes << qMakePair<QByteArray, QVariant>("X-GM-MSGID", *it);
+                    d->pendingAttributes.insert(id, qMakePair<QByteArray, QVariant>("X-GM-MSGID", *it));
                 } else if (str == "BODYSTRUCTURE") {
-                    if (!result.message) {
-                        result.message = MessagePtr(new KMime::Message);
-                    }
                     int pos = 0;
-                    d->parseBodyStructure(*it, pos, result.message.data());
-                    result.message->assemble();
+                    d->parseBodyStructure(*it, pos, message.get());
+                    message->assemble();
+                    d->pendingMessages[id] = message;
                 } else if (str.startsWith("BODY[")) {     //krazy:exclude=strings
                     if (!str.endsWith(']')) {     // BODY[ ... ] might have been split, skip until we find the ]
-                        while (it != content.constEnd() && !(*it).endsWith(']')) {
+                        while (!(*it).endsWith(']')) {
                             ++it;
                         }
+                        ++it;
                     }
 
                     int index;
                     if ((index = str.indexOf("HEADER")) > 0 || (index = str.indexOf("MIME")) > 0) {           // headers
                         if (str[index - 1] == '.') {
                             QByteArray partId = str.mid(5, index - 6);
-                            if (!result.parts.contains(partId)) {
-                                result.parts[partId] = ContentPtr(new KMime::Content);
+                            if (!parts.contains(partId)) {
+                                parts[partId] = ContentPtr(new KMime::Content);
                             }
-                            result.parts[partId]->setHead(*it);
-                            result.parts[partId]->parse();
+                            parts[partId]->setHead(*it);
+                            parts[partId]->parse();
+                            d->pendingParts[id] = parts;
                         } else {
-                            if (!result.message) {
-                                result.message = MessagePtr(new KMime::Message);
-                            }
+                            message->setHead(*it);
                             shouldParseMessage = true;
-                            result.message->setHead(*it);
                         }
                     } else { // full payload
                         if (str == "BODY[]") {
-                            if (!result.message) {
-                                result.message = MessagePtr(new KMime::Message);
-                            }
+                            message->setContent(KMime::CRLFtoLF(*it));
                             shouldParseMessage = true;
-                            result.message->setContent(KMime::CRLFtoLF(*it));
+
+                            d->pendingMessages[id] = message;
                         } else {
                             QByteArray partId = str.mid(5, str.size() - 6);
-                            if (!result.parts.contains(partId)) {
-                                result.parts[partId] = ContentPtr(new KMime::Content);
+                            if (!parts.contains(partId)) {
+                                parts[partId] = ContentPtr(new KMime::Content);
                             }
-                            result.parts[partId]->setBody(*it);
-                            result.parts[partId]->parse();
+                            parts[partId]->setBody(*it);
+                            parts[partId]->parse();
+
+                            d->pendingParts[id] = parts;
                         }
                     }
                 }
             }
 
-            if (result.message && shouldParseMessage && !d->avoidParsing) {
-                result.message->parse();
+            if (shouldParseMessage) {
+                message->parse();
+            }
+
+            // For the headers mode the message is built in several
+            // steps, hence why we wait it to be done until putting it
+            // in the pending queue.
+            if (d->scope.mode == FetchScope::Headers ||
+                    d->scope.mode == FetchScope::HeaderAndContent ||
+                    d->scope.mode == FetchScope::FullHeaders) {
+                d->pendingMessages[id] = message;
             }
-            emit resultReceived(result);
         }
     }
 }
