@@ -40,11 +40,12 @@
 
 #include <QtCore/QTextCodec>
 #include <QtCore/QBuffer>
+#include <QtCore/QRegExp>
 #include <QtCore/QByteArray>
 #include <QtCore/QLatin1Char>
 #include <kcodecs.h>
 
-using namespace KIMAP2;
+using namespace KIMAP;
 
 // This part taken from rfc 2192 IMAP URL Scheme. C. Newman. September 1997.
 // adapted to QT-Toolkit by Sven Carstens <s.carstens@gmx.de> 2000
@@ -67,7 +68,7 @@ static const char especials[17] = "()<>@,;:\"/[]?.= ";
 //@endcond
 
 //-----------------------------------------------------------------------------
-QByteArray KIMAP2::decodeImapFolderName(const QByteArray &inSrc)
+QByteArray KIMAP::decodeImapFolderName(const QByteArray &inSrc)
 {
     unsigned char c, i, bitcount;
     unsigned long ucs4, utf16, bitbuf;
@@ -151,14 +152,14 @@ QByteArray KIMAP2::decodeImapFolderName(const QByteArray &inSrc)
     return dst;
 }
 
-QString KIMAP2::decodeImapFolderName(const QString &inSrc)
+QString KIMAP::decodeImapFolderName(const QString &inSrc)
 {
-    return QString::fromUtf8(decodeImapFolderName(inSrc.toUtf8()).constData());
+    return QString::fromUtf8(decodeImapFolderName(inSrc.toUtf8()).data());
 }
 
 //-----------------------------------------------------------------------------
 
-QByteArray KIMAP2::quoteIMAP(const QByteArray &src)
+QByteArray KIMAP::quoteIMAP(const QByteArray &src)
 {
     uint len = src.length();
     QByteArray result;
@@ -173,7 +174,7 @@ QByteArray KIMAP2::quoteIMAP(const QByteArray &src)
     return result;
 }
 
-QString KIMAP2::quoteIMAP(const QString &src)
+QString KIMAP::quoteIMAP(const QString &src)
 {
     uint len = src.length();
     QString result;
@@ -189,12 +190,12 @@ QString KIMAP2::quoteIMAP(const QString &src)
 }
 
 //-----------------------------------------------------------------------------
-QString KIMAP2::encodeImapFolderName(const QString &inSrc)
+QString KIMAP::encodeImapFolderName(const QString &inSrc)
 {
-    return QString::fromUtf8(encodeImapFolderName(inSrc.toUtf8()).constData());
+    return QString::fromUtf8(encodeImapFolderName(inSrc.toUtf8()).data());
 }
 
-QByteArray KIMAP2::encodeImapFolderName(const QByteArray &inSrc)
+QByteArray KIMAP::encodeImapFolderName(const QByteArray &inSrc)
 {
     unsigned int utf8pos, utf8total, c, utf7mode, bitstogo, utf16flag;
     unsigned int ucs4, bitbuf;
@@ -291,7 +292,7 @@ QByteArray KIMAP2::encodeImapFolderName(const QByteArray &inSrc)
 }
 
 //-----------------------------------------------------------------------------
-QTextCodec *KIMAP2::codecForName(const QString &str)
+QTextCodec *KIMAP::codecForName(const QString &str)
 {
     if (str.isEmpty()) {
         return Q_NULLPTR;
@@ -301,7 +302,7 @@ QTextCodec *KIMAP2::codecForName(const QString &str)
 }
 
 //-----------------------------------------------------------------------------
-const QString KIMAP2::decodeRFC2047String(const QString &str)
+const QString KIMAP::decodeRFC2047String(const QString &str)
 {
     QString throw_away;
 
@@ -309,7 +310,7 @@ const QString KIMAP2::decodeRFC2047String(const QString &str)
 }
 
 //-----------------------------------------------------------------------------
-const QString KIMAP2::decodeRFC2047String(const QString &str,
+const QString KIMAP::decodeRFC2047String(const QString &str,
         QString &charset)
 {
     QString throw_away;
@@ -318,7 +319,7 @@ const QString KIMAP2::decodeRFC2047String(const QString &str,
 }
 
 //-----------------------------------------------------------------------------
-const QString KIMAP2::decodeRFC2047String(const QString &str,
+const QString KIMAP::decodeRFC2047String(const QString &str,
         QString &charset,
         QString &language)
 {
@@ -374,7 +375,7 @@ const QString KIMAP2::decodeRFC2047String(const QString &str,
             }
             pos += 3;
             i += 3;
-//  qCDebug(KIMAP2_LOG) << "Charset:" << charset << "- Language:" << language << "-'" << pos << "'";
+//  qCDebug(KIMAP_LOG) << "Charset:" << charset << "- Language:" << language << "-'" << pos << "'";
         }
         if (valid) {
             mid = pos;
@@ -399,10 +400,10 @@ const QString KIMAP2::decodeRFC2047String(const QString &str,
                         cstr[i] = ' ';
                     }
                 }
-//    qCDebug(KIMAP2_LOG) << "before QP '"
+//    qCDebug(KIMAP_LOG) << "before QP '"
 //    << cstr << "'";
                 cstr = KCodecs::quotedPrintableDecode(cstr);
-//    qCDebug(KIMAP2_LOG) << "after QP '"
+//    qCDebug(KIMAP_LOG) << "after QP '"
 //    << cstr << "'";
             } else {
                 // decode base64 text
@@ -416,7 +417,7 @@ const QString KIMAP2::decodeRFC2047String(const QString &str,
 
             pos = end - 1;
         } else {
-//    qCDebug(KIMAP2_LOG) << "invalid";
+//    qCDebug(KIMAP_LOG) << "invalid";
             //result += "=?";
             //pos = beg -1; // because pos gets increased shortly afterwards
             pos = beg - 2;
@@ -427,7 +428,7 @@ const QString KIMAP2::decodeRFC2047String(const QString &str,
     if (!charset.isEmpty()) {
         QTextCodec *aCodec = codecForName(QLatin1String(charset.toLatin1()));
         if (aCodec) {
-//    qCDebug(KIMAP2_LOG) << "Codec is" << aCodec->name();
+//    qCDebug(KIMAP_LOG) << "Codec is" << aCodec->name();
             return aCodec->toUnicode(result);
         }
     }
@@ -435,13 +436,13 @@ const QString KIMAP2::decodeRFC2047String(const QString &str,
 }
 
 //-----------------------------------------------------------------------------
-const QString KIMAP2::encodeRFC2047String(const QString &str)
+const QString KIMAP::encodeRFC2047String(const QString &str)
 {
     return QLatin1String(encodeRFC2047String(str.toLatin1()));
 }
 
 //-----------------------------------------------------------------------------
-const QByteArray KIMAP2::encodeRFC2047String(const QByteArray &str)
+const QByteArray KIMAP::encodeRFC2047String(const QByteArray &str)
 {
     if (str.isEmpty()) {
         return str;
@@ -559,7 +560,7 @@ const QByteArray KIMAP2::encodeRFC2047String(const QByteArray &str)
 }
 
 //-----------------------------------------------------------------------------
-const QString KIMAP2::encodeRFC2231String(const QString &str)
+const QString KIMAP::encodeRFC2231String(const QString &str)
 {
     if (str.isEmpty()) {
         return str;
@@ -613,7 +614,7 @@ const QString KIMAP2::encodeRFC2231String(const QString &str)
 }
 
 //-----------------------------------------------------------------------------
-const QString KIMAP2::decodeRFC2231String(const QString &str)
+const QString KIMAP::decodeRFC2231String(const QString &str)
 {
     int p = str.indexOf(QLatin1Char('\''));
 
@@ -634,7 +635,7 @@ const QString KIMAP2::decodeRFC2231String(const QString &str)
     QString st = str.mid(l + 1);
     //QString language = str.mid ( p + 1, l - p - 1 );
 
-    //qCDebug(KIMAP2_LOG) << "Charset:" << charset << "Language:" << language;
+    //qCDebug(KIMAP_LOG) << "Charset:" << charset << "Language:" << language;
 
     char ch, ch2;
     p = 0;
